Package: pakret
Title: Cite 'R' Packages on the Fly in 'R Markdown' and 'Quarto'
Version: 0.3.1
Authors@R: 
    person("Arnaud", "Gallou", , "arangacas@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0002-1002-4247"))
Description: References and cites 'R' and 'R' packages on the fly in 'R
    Markdown' and 'Quarto'. 'pakret' provides a minimalist API that
    generates preformatted citations for 'R' and 'R' packages, and adds
    their references to a '.bib' file directly from within your document.
License: GPL (>= 3)
URL: https://arnaudgallou.github.io/pakret/,
        https://github.com/arnaudgallou/pakret
BugReports: https://github.com/arnaudgallou/pakret/issues
Depends: R (>= 3.6.0)
Imports: knitr (>= 1.51), readr (>= 1.0.0), rmarkdown
Suggests: callr (>= 3.7.5), pkgload, testthat (>= 3.0.0), usethis,
        withr (>= 2.5.0)
Config/Needs/website: arnaudgallou/cygne
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-15 10:04:32 UTC; arnaud
Author: Arnaud Gallou [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-1002-4247>)
Maintainer: Arnaud Gallou <arangacas@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-15 10:20:02 UTC
Built: R 4.6.0; ; 2026-04-26 20:21:10 UTC; unix
